@@ -28,12 +28,9 @@
 #include <config.h>
 #endif
 
-#include <rcsc/param/server_param.h>
+#include "bhv_basic_move.h"
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
-#include <rcsc/player/intercept_table.h>
+#include "bhv_basic_tackle.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_go_to_point.h>
@@ -41,9 +38,12 @@
 #include <rcsc/action/neck_turn_to_ball_or_scan.h>
 #include <rcsc/action/neck_turn_to_low_conf_teammate.h>
 
-#include "bhv_basic_tackle.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+#include <rcsc/player/intercept_table.h>
 
-#include "bhv_basic_move.h"
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
 
 /*-------------------------------------------------------------------*/
 /*!
