@@ -28,12 +28,9 @@
 #include <config.h>
 #endif
 
-#include <rcsc/geom/sector_2d.h>
-#include <rcsc/param/server_param.h>
+#include "bhv_basic_offensive_kick.h"
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
+#include "body_kick_to_corner.h"
 
 #include <rcsc/action/body_advance_ball.h>
 #include <rcsc/action/body_kick_multi_step.h>
@@ -43,10 +40,12 @@
 #include <rcsc/action/neck_scan_field.h>
 #include <rcsc/action/neck_turn_to_low_conf_teammate.h>
 
-#include "body_kick_to_corner.h"
-
-#include "bhv_basic_offensive_kick.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
 
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/sector_2d.h>
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -125,9 +124,13 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
         const rcsc::Vector2D body_dir_drib_target
             = wm.self().pos()
             + rcsc::Vector2D::polar2vector(5.0, wm.self().body());
+
+        int max_dir_count = 0;
+        wm.dirRangeCount( wm.self().body(), 20.0, &max_dir_count, NULL, NULL );
+
         if ( body_dir_drib_target.x < rcsc::ServerParam::i().pitchHalfLength() - 1.0
              && body_dir_drib_target.absY() < rcsc::ServerParam::i().pitchHalfWidth() - 1.0
-             && wm.getDirRangeCount( wm.self().body(), 2 ) < 3 * (2 * 2 + 1)
+             && max_dir_count < 3
              )
         {
             // check opponents
@@ -240,6 +243,23 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
         return true;
     }
 
+    // opp is far from me
+    if ( nearest_opp_dist > 3.0 )
+    {
+        rcsc::dlog.addText( rcsc::Logger::TEAM,
+                            "%s:%d: opp far. dribble(%f, %f)"
+                            ,__FILE__, __LINE__,
+                            drib_target.x, drib_target.y );
+        agent->debugClient().addMessage( "OffKickDrib(5)" );
+        rcsc::Body_Dribble( drib_target,
+                            1.0,
+                            rcsc::ServerParam::i().maxPower() * 0.2,
+                            1
+                            ).execute( agent );
+        agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
+        return true;
+    }
+
     if ( nearest_opp_dist > 2.5 )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
