@@ -28,15 +28,7 @@
 #include <config.h>
 #endif
 
-#include <rcsc/soccer_math.h>
-#include <rcsc/geom/line_2d.h>
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/intercept_table.h>
-#include <rcsc/player/debug_client.h>
-
-#include <rcsc/player/logger.h>
+#include "bhv_goalie_basic_move.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_go_to_point.h>
@@ -45,7 +37,14 @@
 #include <rcsc/action/neck_turn_to_ball.h>
 #include <rcsc/action/bhv_go_to_point_look_ball.h>
 
-#include "bhv_goalie_basic_move.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/intercept_table.h>
+#include <rcsc/player/debug_client.h>
+
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/line_2d.h>
+#include <rcsc/soccer_math.h>
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -226,7 +225,7 @@ Bhv_GoalieBasicMove::getBasicDashPower( rcsc::PlayerAgent * agent,
         agent->debugClient().addMessage( "P1" );
         return my_inc;
     }
-    else if ( wm.ball().pos().x > rcsc::ServerParam::i().ourPenaltyAreaLine() )
+    else if ( wm.ball().pos().x > rcsc::ServerParam::i().ourPenaltyAreaLineX() )
     {
         if ( wm.ball().pos().absY() > 20.0 )
         {
