@@ -28,16 +28,11 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-#include <rcsc/geom/ray_2d.h>
-#include <rcsc/geom/rect_2d.h>
-#include <rcsc/common/server_param.h>
+#include "bhv_penalty_kick.h"
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/intercept_table.h>
-#include <rcsc/player/penalty_kick_state.h>
+#include "bhv_goalie_chase_ball.h"
+#include "bhv_goalie_basic_move.h"
+#include "bhv_go_to_static_ball.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/bhv_go_to_point_look_ball.h>
@@ -51,11 +46,16 @@
 #include <rcsc/action/body_stop_ball.h>
 #include <rcsc/action/neck_scan_field.h>
 
-#include "bhv_goalie_chase_ball.h"
-#include "bhv_goalie_basic_move.h"
-#include "bhv_go_to_static_ball.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/intercept_table.h>
+#include <rcsc/player/penalty_kick_state.h>
 
-#include "bhv_penalty_kick.h"
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/rect_2d.h>
+#include <rcsc/geom/ray_2d.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -600,7 +600,7 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
             ? -1.0 : 1.0 );
     const rcsc::Vector2D goal_c(rcsc::ServerParam::i().pitchHalfLength() * onfield_flag, 0.0);
 
-    const double penalty_abs_x = rcsc::ServerParam::i().theirPenaltyAreaLine();
+    const double penalty_abs_x = rcsc::ServerParam::i().theirPenaltyAreaLineX();
 
     const rcsc::PlayerObject * opp_goalie = agent->world().getOpponentGoalie();
     const double goalie_max_speed = 1.0;
@@ -884,7 +884,7 @@ Bhv_PenaltyKick::doGoalie( rcsc::PlayerAgent * agent )
                               rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
     if ( state->onfieldSide() != agent->world().ourSide() )
     {
-        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLine() + 1.0,
+        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
                             -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
                             rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
                             rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
@@ -946,7 +946,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
                               rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
     if ( state->onfieldSide() != agent->world().ourSide() )
     {
-        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLine() + 1.0,
+        our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLineX() + 1.0,
                             -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
                             rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
                             rcsc::ServerParam::i().penaltyAreaWidth() - 2.0);
