@@ -28,12 +28,13 @@
 #include <config.h>
 #endif
 
-#include <rcsc/geom/line_2d.h>
-#include <rcsc/param/server_param.h>
+#include "bhv_set_play.h"
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
+#include "bhv_set_play_free_kick.h"
+#include "bhv_set_play_goal_kick.h"
+#include "bhv_set_play_kick_in.h"
+#include "bhv_set_play_kick_off.h"
+#include "bhv_their_goal_kick_move.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/bhv_before_kick_off.h>
@@ -42,17 +43,16 @@
 #include <rcsc/action/neck_scan_field.h>
 #include <rcsc/action/neck_turn_to_ball_or_scan.h>
 
-#include "bhv_set_play_free_kick.h"
-#include "bhv_set_play_goal_kick.h"
-#include "bhv_set_play_kick_in.h"
-#include "bhv_set_play_kick_off.h"
-#include "bhv_their_goal_kick_move.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
 
-#include "bhv_set_play.h"
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/line_2d.h>
 
 /*-------------------------------------------------------------------*/
 /*!
-  execute action
+
 */
 bool
 Bhv_SetPlay::execute( rcsc::PlayerAgent * agent )
