@@ -28,13 +28,12 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/geom/circle_2d.h>
-#include <rcsc/param/server_param.h>
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
+#include "bhv_set_play_free_kick.h"
+
+#include "bhv_set_play.h"
+#include "bhv_prepare_set_play_kick.h"
+#include "bhv_go_to_static_ball.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_go_to_point.h>
@@ -45,11 +44,13 @@
 #include <rcsc/action/intention_kick.h>
 #include <rcsc/action/neck_scan_field.h>
 
-#include "bhv_set_play.h"
-#include "bhv_prepare_set_play_kick.h"
-#include "bhv_go_to_static_ball.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
 
-#include "bhv_set_play_free_kick.h"
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/circle_2d.h>
+#include <rcsc/math_util.h>
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -145,6 +146,7 @@ Bhv_SetPlayFreeKick::doKick( rcsc::PlayerAgent * agent )
     if ( S_scan_count < 0 )
     {
         S_scan_count++;
+        rcsc::Body_TurnToPoint( face_point ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_ScanField() );
         return;
     }
@@ -153,12 +155,14 @@ Bhv_SetPlayFreeKick::doKick( rcsc::PlayerAgent * agent )
          && wm.teammatesFromSelf().empty() )
     {
         S_scan_count++;
+        rcsc::Body_TurnToPoint( face_point ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_ScanField() );
         return;
     }
 
     if ( wm.time().stopped() != 0 )
     {
+        rcsc::Body_TurnToPoint( face_point ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_ScanField() );
         return;
     }
