@@ -28,8 +28,11 @@
 #include <config.h>
 #endif
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
+#include "bhv_set_play_goal_kick.h"
+
+#include "bhv_set_play.h"
+#include "bhv_prepare_set_play_kick.h"
+#include "bhv_go_to_static_ball.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_clear_ball.h>
@@ -39,15 +42,13 @@
 #include <rcsc/action/neck_scan_field.h>
 #include <rcsc/action/intention_kick.h>
 
-#include "bhv_set_play.h"
-#include "bhv_prepare_set_play_kick.h"
-#include "bhv_go_to_static_ball.h"
+#include <rcsc/player/player_agent.h>
 
-#include "bhv_set_play_goal_kick.h"
+#include <rcsc/common/logger.h>
 
 /*-------------------------------------------------------------------*/
 /*!
-  execute action
+
 */
 bool
 Bhv_SetPlayGoalKick::execute( rcsc::PlayerAgent * agent )
