@@ -28,11 +28,10 @@
 #include <config.h>
 #endif
 
-#include <rcsc/param/server_param.h>
+#include "bhv_set_play_kick_in.h"
 
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
+#include "bhv_set_play.h"
+#include "bhv_prepare_set_play_kick.h"
 
 #include <rcsc/action/basic_actions.h>
 #include <rcsc/action/body_advance_ball.h>
@@ -44,10 +43,11 @@
 #include <rcsc/action/intention_kick.h>
 #include <rcsc/action/neck_scan_field.h>
 
-#include "bhv_set_play.h"
-#include "bhv_prepare_set_play_kick.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
 
-#include "bhv_set_play_kick_in.h"
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
 
 /*-------------------------------------------------------------------*/
 /*!
