@@ -29,7 +29,7 @@
 #endif
 
 #include <rcsc/math_util.h>
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/server_param.h>
 
 #include <rcsc/player/player_agent.h>
 
