@@ -28,22 +28,22 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/common/server_param.h>
-
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
+#include "body_kick_to_corner.h"
 
 #include <rcsc/action/body_hold_ball.h>
 #include <rcsc/action/body_kick_multi_step.h>
 #include <rcsc/action/intention_kick.h>
 
-#include "body_kick_to_corner.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/math_util.h>
 
 /*-------------------------------------------------------------------*/
 /*!
-  execute action
+
  */
 bool
 Body_KickToCorner::execute( rcsc::PlayerAgent * agent )
