@@ -28,19 +28,21 @@
 #include <config.h>
 #endif
 
-#include <rcsc/param/server_param.h>
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/intercept_table.h>
-#include <rcsc/player/debug_client.h>
-#include <rcsc/formation/formation.h>
+#include "role_defensive_half.h"
+
+#include "strategy.h"
 
 #include "bhv_basic_offensive_kick.h"
 #include "bhv_basic_move.h"
 
-#include "strategy.h"
+#include <rcsc/formation/formation.h>
 
-#include "role_defensive_half.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/intercept_table.h>
+#include <rcsc/player/debug_client.h>
+
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
 
 /*-------------------------------------------------------------------*/
 /*!
