@@ -28,23 +28,23 @@
 #include <config.h>
 #endif
 
-#include <rcsc/geom/rect_2d.h>
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
-#include <rcsc/player/world_model.h>
-
-#include <rcsc/action/body_clear_ball.h>
-#include <rcsc/action/neck_scan_field.h>
-#include <rcsc/action/intention_kick.h>
+#include "role_goalie.h"
 
 #include "bhv_goalie_basic_move.h"
 #include "bhv_goalie_chase_ball.h"
 #include "bhv_goalie_free_kick.h"
 
-#include "role_goalie.h"
+#include <rcsc/action/body_clear_ball.h>
+#include <rcsc/action/neck_scan_field.h>
+#include <rcsc/action/intention_kick.h>
+
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+#include <rcsc/player/world_model.h>
+
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/geom/rect_2d.h>
 
 /*-------------------------------------------------------------------*/
 /*!
