@@ -39,14 +39,19 @@
 #include "bhv_set_play_kick_in.h"
 
 #include <rcsc/formation/formation.h>
-#include <rcsc/player/logger.h>
 #include <rcsc/player/intercept_table.h>
 #include <rcsc/player/say_message_builder.h>
+#include <rcsc/player/audio_sensor.h>
+#include <rcsc/player/freeform_parser.h>
 
 #include <rcsc/common/basic_client.h>
+#include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 #include <rcsc/common/player_param.h>
-#include <rcsc/player/audio_sensor.h>
+#include <rcsc/common/audio_memory.h>
+#include <rcsc/common/say_message_parser.h>
+#include <rcsc/common/free_message_parser.h>
+
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/cmd_line_parser.h>
 
@@ -61,7 +66,38 @@
 SamplePlayer::SamplePlayer()
     : PlayerAgent()
 {
+    typedef boost::shared_ptr< rcsc::SayMessageParser > SMP;
 
+    boost::shared_ptr< rcsc::AudioMemory > audio_memory( new rcsc::AudioMemory );
+
+    M_worldmodel.setAudioMemory( audio_memory );
+
+    addSayMessageParser( SMP( new rcsc::BallMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::PassMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::InterceptMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::GoalieMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::OffsideLineMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::DefenseLineMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::WaitRequestMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::PassRequestMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::DribbleMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::BallGoalieMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::OnePlayerMessageParser( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::BallPlayerMessageParser( audio_memory ) ) );
+
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 9 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 8 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 7 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 6 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 5 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 4 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 3 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 2 >( audio_memory ) ) );
+    addSayMessageParser( SMP( new rcsc::FreeMessageParser< 1 >( audio_memory ) ) );
+
+    typedef boost::shared_ptr< rcsc::FreeformParser > FP;
+
+    setFreeformParser( FP( new rcsc::FreeformParser( M_worldmodel ) ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -273,6 +309,35 @@ SamplePlayer::communicationImpl()
     sayOffsideLine();
     saySelf();
 
+#if 0
+    const int len = effector().getSayMessageLength();
+    switch ( len ) {
+    case 7:
+        addSayMessage( new rcsc::FreeMessage< 2 >( "10" ) );
+        break;
+    case 6:
+        addSayMessage( new rcsc::FreeMessage< 3 >( "210" ) );
+        break;
+    case 5:
+        addSayMessage( new rcsc::FreeMessage< 4 >( "3210" ) );
+        break;
+    case 4:
+        addSayMessage( new rcsc::FreeMessage< 5 >( "43210" ) );
+        break;
+    case 3:
+        addSayMessage( new rcsc::FreeMessage< 6 >( "543210" ) );
+        break;
+    case 2:
+        addSayMessage( new rcsc::FreeMessage< 7 >( "6543210" ) );
+        break;
+    case 1:
+        addSayMessage( new rcsc::FreeMessage< 8 >( "76543210" ) );
+        break;
+    default:
+        break;
+    }
+#endif
+
     attentiontoSomeone();
 }
 
