@@ -30,25 +30,12 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cstdio>
-#include <iostream>
-#include <fstream>
-#include <set>
+#include "strategy.h"
 
-#include <rcsc/game_mode.h>
-#include <rcsc/common/server_param.h>
-
-#include <rcsc/player/intercept_table.h>
-#include <rcsc/player/world_model.h>
-#include <rcsc/player/logger.h>
-#include <rcsc/formation/formation_static.h>
-#include <rcsc/formation/formation_bpn.h>
-#include <rcsc/formation/formation_dt.h>
-#include <rcsc/formation/formation_ngnet.h>
-#include <rcsc/formation/formation_uva.h>
+#include "soccer_role.h"
 
 #include "role_sample.h"
 
@@ -60,9 +47,23 @@
 #include "role_side_forward.h"
 #include "role_center_forward.h"
 
-#include "soccer_role.h"
+#include <rcsc/formation/formation_static.h>
+#include <rcsc/formation/formation_bpn.h>
+#include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_ngnet.h>
+#include <rcsc/formation/formation_uva.h>
 
-#include "strategy.h"
+#include <rcsc/player/intercept_table.h>
+#include <rcsc/player/world_model.h>
+
+#include <rcsc/common/logger.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/game_mode.h>
+
+#include <set>
+#include <fstream>
+#include <iostream>
+#include <cstdio>
 
 const std::string Strategy::BEFORE_KICK_OFF_CONF = "before-kick-off.conf";
 const std::string Strategy::GOAL_KICK_OPP_CONF = "goal-kick-opp.conf";
@@ -70,8 +71,8 @@ const std::string Strategy::GOAL_KICK_OUR_CONF = "goal-kick-our.conf";
 const std::string Strategy::GOALIE_CATCH_OPP_CONF = "goalie-catch-opp.conf";
 const std::string Strategy::GOALIE_CATCH_OUR_CONF = "goalie-catch-our.conf";
 
-const std::string Strategy::DEFENSE_FORMATION_CONF = "normal-formation.conf";
-const std::string Strategy::OFFENSE_FORMATION_CONF = "normal-formation.conf";
+const std::string Strategy::DEFENSE_FORMATION_CONF = "defense-formation.conf";
+const std::string Strategy::OFFENSE_FORMATION_CONF = "offense-formation.conf";
 const std::string Strategy::KICKIN_OUR_FORMATION_CONF = "kickin-our-formation.conf";
 const std::string Strategy::SETPLAY_OUR_FORMATION_CONF = "setplay-our-formation.conf";
 
