@@ -32,12 +32,13 @@
 #ifndef AGENT2D_STRATEGY_H
 #define AGENT2D_STRATEGY_H
 
-#include <string>
-#include <vector>
-#include <boost/shared_ptr.hpp>
-
 #include <rcsc/geom/vector_2d.h>
 
+#include <boost/shared_ptr.hpp>
+#include <map>
+#include <vector>
+#include <string>
+
 namespace rcsc {
 
 class WorldModel;
@@ -69,7 +70,7 @@ private:
     std::map< std::string, RoleCreator > M_role_factory;
     std::map< std::string, FormationCreator > M_formation_factory;
 
-    std::vector< rcsc::Vector2D > M_before_kick_off_pos;
+    FormationPtr M_before_kick_off_formation;
     std::vector< rcsc::Vector2D > M_goal_kick_opp_pos;
     std::vector< rcsc::Vector2D > M_goal_kick_our_pos;
     std::vector< rcsc::Vector2D > M_goalie_catch_opp_pos;
@@ -96,11 +97,11 @@ public:
                                        const rcsc::Formation & formation,
                                        const rcsc::WorldModel & world ) const;
 
-    boost::shared_ptr< 
+    boost::shared_ptr<
         rcsc::Formation > createFormation( const std::string & type_name ) const;
 
     boost::shared_ptr<
-        SoccerRole > createRole( const int number, 
+        SoccerRole > createRole( const int number,
                                  const rcsc::WorldModel & world ) const;
 
 private:
@@ -111,21 +112,9 @@ private:
     bool readStaticPositions( const std::string & filepath,
                               std::vector< rcsc::Vector2D > & positions );
 
-    bool readBeforeKickOffPos( const std::string & configpath );
-    bool readGoalKickOppPos( const std::string & configpath );
-    bool readGoalKickOurPos( const std::string & configpath );
-    bool readGoalieCatchOppPos( const std::string & configpath );
-    bool readGoalieCatchOurPos( const std::string & configpath );
-
     /////////////////////////////////////////////////////////
     FormationPtr readFormation( const std::string & filepath );
 
-    bool readOffenseFormation( const std::string & configpath );
-    bool readDefenseFormation( const std::string & configpath );
-
-    bool readKickInOurFormation( const std::string & configpath );
-    bool readSetPlayOurFormation( const std::string & configpath );
-
 public:
     enum BallArea {
         BA_CrossBlock, BA_DribbleBlock, BA_DribbleAttack, BA_Cross,
